/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */
package de.bsvrz.sys.startstopp.skriptvew;

import static org.junit.Assert.*;

import java.util.Iterator;
import java.util.List;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Klasse zum Testen der Klasse StartStoppHistorie
 * @author Dambach Werke GmbH
 *
 */
public class StartStoppHistorieTest
{
  /**
   * Instanz der History
   */
  private static StartStoppHistorie m_ssh;

  /**
   * History Daten
   */
  private List<HistoryData> m_history;

  /**
   * @throws java.lang.Exception
   */
  @BeforeClass
  public static void setUpBeforeClass() throws Exception
  {
    // Basisverzeichnis initialisieren
    
    StartStoppApp.setStartStoppKonfiguration( "C:\\JUnit");
    
    m_ssh = StartStoppHistorie.getInstanz();
  }

  /**
   * @throws java.lang.Exception
   */
  @AfterClass
  public static void tearDownAfterClass() throws Exception
  {
  }

  /**
   * @throws java.lang.Exception
   */
  @Before
  public void setUp() throws Exception
  {
  }

  /**
   * @throws java.lang.Exception
   */
  @After
  public void tearDown() throws Exception
  {
  }

  /**
   * Methode prft die Historyfunktionalitten
   * Geprft werden die Methoden:
   * -getHistory
   * -addHistory
   * -getHoschsteVersionsNummer
   * -getAktuellerHashwert 
   */
  @Test
  public void testHistory()
  {
    m_history = m_ssh.getHistory();
    int counter = m_history.size();
    
    int akt      = m_ssh.getHoechsteVersionsNummer();
    int hashwert = 4710;
        
    for (int i=0; i<10; ++i)
    {
      akt++;
      hashwert++;
      
      m_ssh.addHistory( "" + akt, "01.01.2008 0:00", "Benutzer", "Ursache", "" + hashwert );
      
      m_history = m_ssh.getHistory();
      if (m_history.size() != (counter + 1 + i))
        fail( "History nicht bernommen" );
      
      if (m_ssh.getHoechsteVersionsNummer() != akt)
        fail ("Versionsnummer nicht bernommen");
    }
    
    if (!m_ssh.getAktuellerHashwert().equals( "" + hashwert))
      fail ("Hashwert stimmt nicht");
  }
}
